==> ci-auto-update-5.0.4.zip: elabftw_ynh/README_zh_Hans.md <==
<!--
注意：此 README 由 <https://github.com/YunoHost/apps/tree/master/tools/readme_generator> 自动生成
请勿手动编辑。
-->

# YunoHost 上的 eLabFTW

[![集成程度](https://dash.yunohost.org/integration/elabftw.svg)](https://dash.yunohost.org/appci/app/elabftw) ![工作状态](https://ci-apps.yunohost.org/ci/badges/elabftw.status.svg) ![维护状态](https://ci-apps.yunohost.org/ci/badges/elabftw.maintain.svg)

[![使用 YunoHost 安装 eLabFTW](https://install-app.yunohost.org/install-with-yunohost.svg)](https://install-app.yunohost.org/?app=elabftw)

*[阅读此 README 的其它语言版本。](./ALL_README.md)*

> *通过此软件包，您可以在 YunoHost 服务器上快速、简单地安装 eLabFTW。*  
> *如果您还没有 YunoHost，请参阅[指南](https://yunohost.org/install)了解如何安装它。*

## 概况

eLabFTW is an electronic lab notebook manager for research teams.

It lets you store and organize your research experiments easily. It also features a database where any kind of objects (such as antibodies, plasmids, cell lines, boxes, etc.) can be stored. It is accessed via the browser. Several research teams can be hosted on the same installation. This means eLabFTW can be installed at the institute level and host all team members at the same place. This is what is done at Institut Curie and in several other research centers around the globe.

**分发版本：** 5.0.4~ynh1

**演示：** <https://demo.elabftw.net/login.php>

## 截图

![eLabFTW 的截图](./doc/screenshots/screen-1.jpg)

## 文档与资源

- 官方应用网站： <https://www.elabftw.net>
- 官方管理文档： <https://doc.elabftw.net/>
- 上游应用代码库： <https://github.com/elabftw/elabftw>
- YunoHost 商店： <https://apps.yunohost.org/app/elabftw>
- 报告 bug： <https://github.com/YunoHost-Apps/elabftw_ynh/issues>

## 开发者信息

请向 [`testing` 分支](https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing) 发送拉取请求。

如要尝试 `testing` 分支，请这样操作：

```bash
sudo yunohost app install https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing --debug
或
sudo yunohost app upgrade elabftw -u https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing --debug
```

**有关应用打包的更多信息：** <https://yunohost.org/packaging_apps>

==> ci-auto-update-5.1.2.zip: elabftw_ynh/README_zh_Hans.md <==
<!--
注意：此 README 由 <https://github.com/YunoHost/apps/tree/master/tools/readme_generator> 自动生成
请勿手动编辑。
-->

# YunoHost 上的 eLabFTW

[![集成程度](https://dash.yunohost.org/integration/elabftw.svg)](https://ci-apps.yunohost.org/ci/apps/elabftw/) ![工作状态](https://ci-apps.yunohost.org/ci/badges/elabftw.status.svg) ![维护状态](https://ci-apps.yunohost.org/ci/badges/elabftw.maintain.svg)

[![使用 YunoHost 安装 eLabFTW](https://install-app.yunohost.org/install-with-yunohost.svg)](https://install-app.yunohost.org/?app=elabftw)

*[阅读此 README 的其它语言版本。](./ALL_README.md)*

> *通过此软件包，您可以在 YunoHost 服务器上快速、简单地安装 eLabFTW。*  
> *如果您还没有 YunoHost，请参阅[指南](https://yunohost.org/install)了解如何安装它。*

## 概况

eLabFTW is an electronic lab notebook manager for research teams.

It lets you store and organize your research experiments easily. It also features a database where any kind of objects (such as antibodies, plasmids, cell lines, boxes, etc.) can be stored. It is accessed via the browser. Several research teams can be hosted on the same installation. This means eLabFTW can be installed at the institute level and host all team members at the same place. This is what is done at Institut Curie and in several other research centers around the globe.

**分发版本：** 5.1.2~ynh1

**演示：** <https://demo.elabftw.net/login.php>

## 截图

![eLabFTW 的截图](./doc/screenshots/screen-1.jpg)

## 文档与资源

- 官方应用网站： <https://www.elabftw.net>
- 官方管理文档： <https://doc.elabftw.net/>
- 上游应用代码库： <https://github.com/elabftw/elabftw>
- YunoHost 商店： <https://apps.yunohost.org/app/elabftw>
- 报告 bug： <https://github.com/YunoHost-Apps/elabftw_ynh/issues>

## 开发者信息

请向 [`testing` 分支](https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing) 发送拉取请求。

如要尝试 `testing` 分支，请这样操作：

```bash
sudo yunohost app install https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing --debug
或
sudo yunohost app upgrade elabftw -u https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing --debug
```

**有关应用打包的更多信息：** <https://yunohost.org/packaging_apps>
